import { Switch, Route } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { ThemeProvider } from "@/lib/themes/ThemeContext";
import { useUser } from "@/hooks/use-user";
import { useLocation } from "wouter";
import { Suspense, lazy } from "react";
import { useEffect } from "react";
import { ErrorBoundary } from "@/components/error-boundary";

// Lazy load components with chunk names for better debugging
const NotFound = lazy(() => import("@/pages/not-found" /* webpackChunkName: "not-found" */));
const Editor = lazy(() => import("@/pages/Editor" /* webpackChunkName: "editor" */));
const Themes = lazy(() => import("@/pages/Themes" /* webpackChunkName: "themes" */));
const Dashboard = lazy(() => import("@/pages/Dashboard" /* webpackChunkName: "dashboard" */));
const AdminDashboard = lazy(() => import("@/pages/AdminDashboard" /* webpackChunkName: "admin" */));
const Analytics = lazy(() => import("@/pages/Analytics" /* webpackChunkName: "analytics" */));
const AuthPage = lazy(() => import("@/pages/auth-page" /* webpackChunkName: "auth" */));
const Templates = lazy(() => import("@/pages/Templates" /* webpackChunkName: "templates" */));

// Enhanced loading component with progress indication
const LoadingFallback = () => (
  <div className="loading-container">
    <div className="loading-content">
      <div className="loading-spinner">
        <div className="loading-ring" />
      </div>
      <span className="loading-text">Loading...</span>
    </div>
  </div>
);

function ProtectedRoute({ component: Component, requireAdmin = false }: { component: React.ComponentType, requireAdmin?: boolean }) {
  const { user, isLoading } = useUser();
  const [, navigate] = useLocation();

  useEffect(() => {
    if (!isLoading) {
      if (!user) {
        navigate("/auth");
      } else if (requireAdmin && !user.isAdmin) {
        navigate("/dashboard");
      }
    }
  }, [user, isLoading, navigate, requireAdmin]);

  if (isLoading) {
    return <LoadingFallback />;
  }

  if (!user || (requireAdmin && !user.isAdmin)) {
    return null;
  }

  return (
    <ErrorBoundary>
      <Suspense fallback={<LoadingFallback />}>
        <Component />
      </Suspense>
    </ErrorBoundary>
  );
}

function AuthRoute({ component: Component }: { component: React.ComponentType }) {
  const { user, isLoading } = useUser();
  const [, navigate] = useLocation();

  useEffect(() => {
    if (!isLoading && user) {
      navigate("/dashboard");
    }
  }, [user, isLoading, navigate]);

  if (isLoading) {
    return <LoadingFallback />;
  }

  return (
    <ErrorBoundary>
      <Suspense fallback={<LoadingFallback />}>
        <Component />
      </Suspense>
    </ErrorBoundary>
  );
}

function Router() {
  return (
    <Switch>
      <Route path="/auth" component={() => <AuthRoute component={AuthPage} />} />
      <Route path="/dashboard" component={() => <ProtectedRoute component={Dashboard} />} />
      <Route path="/templates" component={() => <ProtectedRoute component={Templates} />} />
      <Route path="/dashboard/orders" component={() => <ProtectedRoute component={Dashboard} />} />
      <Route path="/dashboard/blogs" component={() => <ProtectedRoute component={Dashboard} />} />
      <Route path="/dashboard/domains" component={() => <ProtectedRoute component={Dashboard} />} />
      <Route path="/dashboard/analytics" component={() => <ProtectedRoute component={Analytics} />} />
      <Route path="/admin" component={() => <ProtectedRoute component={AdminDashboard} requireAdmin={true} />} />
      <Route path="/editor/:id" component={() => <ProtectedRoute component={Editor} />} />
      <Route path="/themes" component={() => <ProtectedRoute component={Themes} />} />
      <Route path="/" component={() => <ProtectedRoute component={Dashboard} />} />
      <Route component={NotFound} />
    </Switch>
  );
}

function App() {
  return (
    <ErrorBoundary>
      <ThemeProvider>
        <QueryClientProvider client={queryClient}>
          <Suspense fallback={<LoadingFallback />}>
            <Router />
          </Suspense>
          <Toaster />
        </QueryClientProvider>
      </ThemeProvider>
    </ErrorBoundary>
  );
}

export default App;